<?php

namespace Litecms\Information\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Information\Models\Information;

class InformationPolicy
{

    /**
     * Determine if the given user can view the information.
     *
     * @param UserPolicy $user
     * @param Information $information
     *
     * @return bool
     */
    public function view(UserPolicy $user, Information $information)
    {
        if ($user->canDo('information.information.view') && $user->isAdmin()) {
            return true;
        }

        return $information->user_id == user_id() && $information->user_type == user_type();
    }

    /**
     * Determine if the given user can create a information.
     *
     * @param UserPolicy $user
     * @param Information $information
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('information.information.create');
    }

    /**
     * Determine if the given user can update the given information.
     *
     * @param UserPolicy $user
     * @param Information $information
     *
     * @return bool
     */
    public function update(UserPolicy $user, Information $information)
    {
        if ($user->canDo('information.information.edit') && $user->isAdmin()) {
            return true;
        }

        return $information->user_id == user_id() && $information->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given information.
     *
     * @param UserPolicy $user
     * @param Information $information
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Information $information)
    {
        return $information->user_id == user_id() && $information->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given information.
     *
     * @param UserPolicy $user
     * @param Information $information
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Information $information)
    {
        if ($user->canDo('information.information.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given information.
     *
     * @param UserPolicy $user
     * @param Information $information
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Information $information)
    {
        if ($user->canDo('information.information.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
